# Unboxing Amazon Timestream

## Importer

Preconditions:
1. Create a [Finnhub](https://finnhub.io/) account
2. [Get your API key](https://finnhub.io/dashboard)
3. Install Node.js
4. Run `npm install` to install the dependencies
5. Create a Timestream database named `usstocks`
6. Within that database, create a `trades` table

To start the importer, run `FINNHUB_TOKEN=*** node index.js`.

## Analytics

Get the Amazon share price (min/max) with a 1-minute granularity for the last 30 minutes.

```
SELECT
  BIN(time, 1m) as binned_time,
  MIN(measure_value::double) AS min_price,
  MAX(measure_value::double) AS max_price
FROM usstocks.trades
WHERE time >= ago(30m) AND measure_name='price' AND symbol='AMZN'
GROUP BY BIN(time, 1m)
ORDER BY binned_time
```

Get the average Amazon share price and the traded volume with a 1-minute granularity for the last 30 minutes.

```
SELECT
  BIN(time, 1m) as binned_time,
  AVG(CASE WHEN measure_name = 'price' THEN measure_value::double ELSE NULL END) AS avg_price,
  SUM(CASE WHEN measure_name = 'size' THEN measure_value::bigint ELSE NULL END) AS sum_size
FROM usstocks.trades
WHERE time >= ago(30m) AND measure_name in ('price', 'size') AND symbol='AMZN'
GROUP BY BIN(time, 1m)
ORDER BY binned_time
```

```
SELECT
  BIN(time, 1m) as binned_time,
  AVG(CASE WHEN symbol = 'AMZN' AND measure_name = 'price' THEN measure_value::double ELSE NULL END) AS avg_amzn_price,
  SUM(CASE WHEN symbol = 'AMZN' AND measure_name = 'size' THEN measure_value::bigint ELSE NULL END) AS sum_amzn_size,
  AVG(CASE WHEN symbol = 'MSFT' AND measure_name = 'price' THEN measure_value::double ELSE NULL END) AS avg_msft_price,
  SUM(CASE WHEN symbol = 'MSFT' AND measure_name = 'size' THEN measure_value::bigint ELSE NULL END) AS sum_msft_size
FROM usstocks.trades
WHERE time >= ago(30m) AND measure_name in ('price', 'size') AND symbol IN ('AMZN', 'MSFT')
GROUP BY BIN(time, 1m)
```
